@@ -1,5 +1,5 @@
 # Copyright (c) 2007-2008 Infrae. All rights reserved.
-# $Id: Common.py 29939 2008-08-01 12:35:21Z sylvain $
+# $Id: Common.py 30442 2008-08-25 11:06:13Z sylvain $
 
 import os.path
 import re
@@ -58,9 +58,9 @@ class BaseRecipe(object):
         Options can only contains strings.
         """
         if self.options.get('export_info', False):
-            self.options['updated'] = '\n'.join(self.updated)
+            self.options['updated'] = str('\n'.join(self.updated))
             str_revisions = ['%s %s' % r for r in self.revisions.items() if r[1]]
-            self.options['revisions'] = '\n'.join(str_revisions)
+            self.options['revisions'] = str('\n'.join(sorted(str_revisions)))
 
 
     def _updateAllRevisionInformation(self):
